@@ -9,14 +9,16 @@ OC.L10N.register(
     "Tags" : "Tags",
     "Places" : "Joylar",
     "Back" : "Orqaga",
-    "Save" : "Save",
+    "Save" : "Saqlash",
     "Copy public link" : "Umumiy havoladan nusxa oling",
     "Favorite" : "Favorite",
-    "Back to {folder}" : "{folder}ga qaytish",
     "Add to {destination}" : " {destination}ni qo`shish",
     "Home" : "Home",
+    "View" : "Ko'rish",
     "Remove from favorites" : "Sevimlilardan olib tashlang",
+    "Last week" : "O`tgan yil",
     "Details" : "Details",
+    "Back to {folder}" : "{folder}ga qaytish",
     "Add" : "Add"
 },
 "nplurals=1; plural=0;");
